===============================
BED annotator
===============================

.. image:: https://img.shields.io/travis/olgabot/outrigger.svg
        :target: https://travis-ci.org/olgabot/outrigger

.. image:: https://img.shields.io/pypi/v/outrigger.svg
        :target: https://pypi.python.org/pypi/outrigger


Exon ontology is an attempt to catalogue scripts used to annotate exons and their functions

* Free software: BSD license
* Documentation: https://olgabot.github.io/outrigger

Features
--------

* TODO
